package com.tzld.piaoquan.recommend.server.service;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.data.Record;
import com.tzld.piaoquan.recommend.server.common.base.Constant;
import com.tzld.piaoquan.recommend.server.util.ODPSManager;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author sunxy
 */
@Component
public class SyncFlowPoolRecentTopVideoJob {

    @Resource
    private ODPSManager odpsManager;

    @Resource
    private RedisTemplate<String, Object> redisTemplate;

    public void syncFlowPoolRecentTopVideo() {
        // 执行 ODPS Sql，获取数据
        List<Long> videoIds = queryTopVideoIdsByLast6Hour(100);
        if (CollectionUtils.isEmpty(videoIds)) {
            return;
        }
        // 将数据写入 Redis
        redisTemplate.opsForValue().set(Constant.FLOW_POOL_RECENT_TOP_VIDEO_REDIS_KEY,
                JSONObject.toJSONString(videoIds));
    }

    private List<Long> queryTopVideoIdsByLast6Hour(Integer topNum) {
        String sql = "SELECT videoid FROM loghubods.flow_pool_video_info_per_hour " +
                "ORDER BY 1d_return_cnt DESC LIMIT " + topNum + ";";
        List<Record> records = odpsManager.query(sql);
        if (records == null || records.size() == 0) {
            return null;
        }
        return records.stream().map(record -> record.getBigint(0)).collect(Collectors.toList());
    }


}
